@@ -1526,7 +1526,7 @@ impl StateHub {
     }
 
     fn verbosely(&self, text: impl fmt::Display) -> io::Result<()> {
-        if self.verbose {
+        if !self.json && self.verbose {
             self.stdout.write_line(&text.to_string())
         } else {
             Ok(())
@@ -1534,9 +1534,11 @@ impl StateHub {
     }
 
     fn inform(&self, text: impl fmt::Display) {
-        let text = format!("{}", self.style.apply_to(text));
-        if !text.is_empty() {
-            self.stdout.write_line(&text).ok();
+        if !self.json {
+            let text = format!("{}", self.style.apply_to(text));
+            if !text.is_empty() {
+                self.stdout.write_line(&text).ok();
+            }
         }
     }
 
